@@ -1,10 +1,10 @@
-## -*- Mode: CPerl -*-
+## -*- Mode: Perl -*-
 ##  + CPerl pukes on '/esg'-modifiers.... bummer
 ##
-## $Id: Dev.pm 6820 2013-09-24 11:15:50Z moocow $
+## $Id: Dev.pm 1975 2007-04-16 07:59:41Z moocow $
 ##
 ## File: PDL::VectorValued::Dev.pm
-## Author: Bryan Jurish <moocow@cpan.org>
+## Author: Bryan Jurish <moocow@ling.uni-potsdam.de>
 ## Description: Vector utilities for PDL: development
 ##======================================================================
 
@@ -24,9 +24,6 @@ our @EXPORT_OK =
    ##-- High-level macro expansion
    qw(vvpp_def vvpp_expand),
    ##
-   ##-- Type utilities
-   qw(vv_indx_sig vv_indx_typedef),
-   ##
    ##-- Macro expansion subs
    qw(vvpp_pdlvar_basename),
    qw(vvpp_expand_cmpvec vvpp_cmpvec_code),
@@ -149,54 +146,7 @@ sub vvpp_expand_cmpvec {
 }
 
 ##======================================================================
-## PP Utilities: Types
-=pod
-
-=head1 Type Utilities
-
-=cut
-
-##--------------------------------------------------------------
-## $sigtype = vv_indx_sig()
-=pod
-
-=head2 vv_indx_sig()
-
-Returns a signature type for representing PDL indices.
-For PDL E<gt>= v2.007 this should be C<PDL_Index>, otherwise it will be C<int>.
-
-=cut
-
-sub vv_indx_sig {
-  require PDL::Core;
-  return defined(&PDL::indx) ? 'indx' : 'int';
-}
-
-##--------------------------------------------------------------
-## $sigtype = vv_indx_typedef()
-=pod
-
-=head2 vv_indx_typedef()
-
-Returns a C typedef for the C<PDL_Indx> type if running under
-PDL E<lt>= v2.007, otherwise just a comment.  You can call this
-from client PDL::PP modules as
-
- pp_addhdr(PDL::VectorValued::Dev::vv_indx_typedef);
-
-=cut
-
-sub vv_indx_typedef {
-  require PDL::Core;
-  if (defined(&PDL::indx)) {
-    return "/*-- PDL_Indx built-in for PDL >= v2.007 --*/\n";
-  }
-  return "typedef int PDL_Indx; /*-- PDL_Indx typedef for PDL <= v2.007 --*/\n";
-}
-
-
-##======================================================================
-## PP Utilities: Macro Expansion
+## PP Utiltiies
 =pod
 
 =head1 Macro Expansion Utilities
@@ -369,7 +319,7 @@ perl by Larry Wall.
 
 =head1 AUTHOR
 
-Bryan Jurish E<lt>moocow@cpan.orgE<gt>
+Bryan Jurish E<lt>jurish@ling.uni-potsdam.deE<gt>
 
 PDL by Karl Glazebrook, Tuomas J. Lukka, Christian Soeller, and others.
 
