@@ -1,13 +1,12 @@
 ##
 ## File: PDL::VectorValued::Version.pm
-## Author: Bryan Jurish <moocow@cpan.org>
+## Author: Bryan Jurish <moocow@ling.uni-potsdam.de>
 ## Description: Vector utilities for PDL: version
 ##  + this lives in a separate file so that both compile-time and
 ##    runtime subsystems can use it
 ##======================================================================
 
-package PDL::VectorValued::Version;
-our $VERSION = '0.07.001';
-$PDL::VectorValued::VERSION = $VERSION;
+package PDL::VectorValued;
+our $VERSION = '0.04';
 
 1; ##-- make perl happy
